@@ -1,7 +1,6 @@
 from typing import List, Union
 
 import napari
-import numpy as np
 import pandas as pd
 from qtpy import QtCore, QtGui, QtWidgets
 
@@ -238,41 +237,6 @@ class Tabulour(QtWidgets.QTableView):
         name = QtWidgets.QFileDialog.getSaveFileName(self, "Save File")[0]
         self._data.get_data().to_csv(name + ".csv", index=False)
 
-    def _make_boxes(self, item):
-
-        self._boxes = []
-        self._sizes = []
-        if (
-            self._size_key is not None
-            and self._size_key in self._data.get_data()
-            and self._unique_cell_val is not None
-        ):
-            current_tracklet = self._unique_cell_val
-            current_tracklet_properties = self._unique_cell_val_properties
-            print(current_tracklet_properties.shape, current_tracklet.shape)
-            ndim = current_tracklet.shape[1] - 1
-            for i in range(current_tracklet.shape[0]):
-                # TZYX
-                current_tracklet_location = current_tracklet[i][1:]
-                current_tracklet_props = current_tracklet_properties[i][-2:-1]
-                self._boxes.append(
-                    [location for location in current_tracklet_location]
-                )
-                self._sizes.append(
-                    [volume for volume in current_tracklet_props]
-                )
-            for layer in list(self._viewer.layers):
-                if "Boxes" == layer.name:
-                    self._viewer.layers.remove(layer)
-            self._viewer.add_points(
-                np.array(self._boxes),
-                size=np.array(self._sizes),
-                name="Boxes",
-                face_color=[0] * 4,
-                edge_color="green",
-                ndim=ndim,
-            )
-
     def _on_user_click(self, item):
 
         row = self.proxy.mapToSource(item).row()
@@ -298,7 +262,9 @@ class Tabulour(QtWidgets.QTableView):
                 and self._id_key in self._data.get_data()
             ):
 
-                value_of_interest = self._data.get_data()[self._id_key][row]
+                value_of_interest = int(
+                    self._data.get_data()[self._id_key][row]
+                )
                 if self._unique_tracks is not None:
                     (
                         self._unique_cell_val,
@@ -309,9 +275,9 @@ class Tabulour(QtWidgets.QTableView):
 
                 if self._plugin.track_id_box is not None:
 
-                    dividing_normal = self._data.get_data()[
-                        self._dividing_key
-                    ][row]
+                    dividing_normal = eval(
+                        self._data.get_data()[self._dividing_key][row]
+                    )
                     if dividing_normal:
                         self.plugin.track_model_type.value = "Dividing"
                         self.plugin.track_id_box.choices = (
